@@ -40,8 +40,8 @@ FIRST_BASE_PLUS_2_CUTOFF = {
     'dWAR': 0.8
 }
 FIRST_BASE_PLUS_1_CUTOFF = {
-    'drs': 0,
-    'tzr': 0,
+    'drs': 4,
+    'tzr': 4,
     'dWAR': -0.25
 }
 # MINIMUM REQUIRED GAMES PLAYED AT A POSITION TO QUALIFY
@@ -86,7 +86,7 @@ BASELINE_PITCHER = {
         'command': 3.0,
         'outs': 15.75,
         'so': 4.5,
-        'bb': 1.175,
+        'bb': 1.35,
         '1b': 1.95,
         '2b': 0.67,
         '3b': 0.00,
@@ -96,7 +96,7 @@ BASELINE_PITCHER = {
         'command': 3.0,
         'outs': 16.0,
         'so': 4.1,
-        'bb': 1.125,
+        'bb': 1.35,
         '1b': 2.0,
         '2b': 0.62,
         '3b': 0.00,
@@ -106,7 +106,7 @@ BASELINE_PITCHER = {
         'command': 3.3,
         'outs': 16.7,
         'so': 4.20,
-        'bb': 0.75,
+        'bb': 1.05,
         '1b': 1.40,
         '2b': 0.51,
         '3b': 0.01,
@@ -116,7 +116,7 @@ BASELINE_PITCHER = {
         'command': 3.9,
         'outs': 16.3,
         'so': 3.65,
-        'bb': 0.95,
+        'bb': 1.2,
         '1b': 1.93,
         '2b': 0.54,
         '3b': 0.13,
@@ -126,7 +126,7 @@ BASELINE_PITCHER = {
         'command': 3.85,
         'outs': 16.35,
         'so': 4.0,
-        'bb': 0.87,
+        'bb': 1.1,
         '1b': 2.1,
         '2b': 0.48,
         '3b': 0.09,
@@ -136,7 +136,7 @@ BASELINE_PITCHER = {
         'command': 3.9,
         'outs': 16.2,
         'so': 3.87,
-        'bb': 0.93,
+        'bb': 1.25,
         '1b': 2.05,
         '2b': 0.50,
         '3b': 0.09,
@@ -154,7 +154,7 @@ BASELINE_HITTER = {
         'command': 7.7,
         'outs': 3.7,
         'so': 0.2,
-        'bb': 4.60,
+        'bb': 4.4,
         '1b': 6.65,
         '1b+': 0.41,
         '2b': 1.94,
@@ -165,7 +165,7 @@ BASELINE_HITTER = {
         'command': 7.8,
         'outs': 3.9,
         'so': 1.31,
-        'bb': 4.20,
+        'bb': 4.45,
         '1b': 6.7,
         '1b+': 0.63,
         '2b': 1.95,
@@ -176,7 +176,7 @@ BASELINE_HITTER = {
         'command': 9.4,
         'outs': 6.0,
         'so': 2.09,
-        'bb': 3.3,
+        'bb': 3.35,
         '1b': 6.0,
         '1b+': 0.2,
         '2b': 1.94,
@@ -198,7 +198,7 @@ BASELINE_HITTER = {
         'command': 8.7,
         'outs': 7.4,
         'so': 2.3,
-        'bb': 2.45,
+        'bb': 2.9,
         '1b': 6.59,
         '1b+': 0.12,
         '2b': 1.25,
@@ -209,7 +209,7 @@ BASELINE_HITTER = {
         'command': 8.8,
         'outs': 7.4,
         'so': 2.4,
-        'bb': 2.9,
+        'bb': 3.3,
         '1b': 6.0,
         '1b+': 0.12,
         '2b': 1.3,
@@ -496,14 +496,14 @@ POINT_CATEGORY_WEIGHTS = {
             'onbase': 485,
             'average': 55,
             'slugging': 210,
-            'out_distribution': 20,
+            'out_distribution': 30,
         },
         'relief_pitcher': {
             'ip': 0, # IP IS ADJUSTED ELSEWHERE
             'onbase': 110,
             'average': 20,
             'slugging': 90,
-            'out_distribution': 10,
+            'out_distribution': 20,
         }
     },
     '2001': {
@@ -520,14 +520,14 @@ POINT_CATEGORY_WEIGHTS = {
             'onbase': 470,
             'average': 35,
             'slugging': 255,
-            'out_distribution': 20,
+            'out_distribution': 30,
         },
         'relief_pitcher': {
             'ip': 0, # IP IS ADJUSTED ELSEWHERE
-            'onbase': 145,
+            'onbase': 174,
             'average': 25,
-            'slugging': 120,
-            'out_distribution': 10,
+            'slugging': 112,
+            'out_distribution': 20,
         }
     },
     '2002': {
@@ -932,6 +932,19 @@ POINTS_NORMALIZER_MULTIPLIER = {
     },
 }
 
+"""
+POINTS_NORMALIZER_RELIEVER_MULTIPLIER
+  - WHAT TO MULTIPLY MEDIAN FOR POSITION PLAYER / STARTERS BY
+"""
+POINTS_NORMALIZER_RELIEVER_MULTIPLIER = {
+    '2000': 2.0,
+    '2001': 1.5,
+    '2002': 2.0,
+    '2003': 2.0,
+    '2004': 2.0,
+    '2005': 2.0,
+}
+
 """
 POINTS_RELIEVER_IP_MULTIPLIER
   - WHAT PERCENT OF POINTS TO GIVE FOR 2ND INNING OF RELIEF
@@ -972,8 +985,8 @@ ONBASE_PCT_RANGE = {
             'max': 0.400
         },
         'relief_pitcher': {
-            'min': 0.250,
-            'max': 0.370
+            'min': 0.240,
+            'max': 0.360
         },
         'position_player': {
             'min': 0.290,
@@ -1739,8 +1752,8 @@ TEAM_LOGO_ALTERNATES = {
         '1': list(range(1900,1950)),
     },
     'OAK': {
-        '1': list(range(1970,1992)),
-        '2': list(range(1992,2019)),
+        '1': list(range(1970,1982)),
+        '2': list(range(1982,1993)),
     },
     'PHI': {
         '1': list(range(1900,1950)),
@@ -1774,6 +1787,9 @@ TEAM_LOGO_ALTERNATES = {
         '2': list(range(1927,1965)),
         '3': list(range(1965,1998)),
     },
+    'TBD': {
+        '1': list(range(1998,2001)),
+    },
     'TEX': {
         '1': list(range(1972,1982)),
         '2': list(range(1982,1994)),
